@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: mhtxthtml.pl,v 2.22 2002/10/11 01:57:53 ehood Exp $
+##	$Id: mhtxthtml.pl,v 2.22.2.1 2002/12/22 00:43:56 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -150,30 +150,56 @@ sub filter {
     $base =~ s|(.*/).*|$1|;
 
     ## Strip out certain elements/tags to support proper inclusion
-    $$data =~ s|<!doctype\s[^>]*>||io;
-    $$data =~ s|</?html\b[^>]*>||gio;
-    $$data =~ s|</?x-html\b[^>]*>||gio;
     $$data =~ s|<head\s*>[\s\S]*</head\s*>||io;
+    1 while ($$data =~ s|<!doctype\s[^>]*>||io);
+    1 while ($$data =~ s|</?html\b[^>]*>||gio);
+    1 while ($$data =~ s|</?x-html\b[^>]*>||gio);
+    1 while ($$data =~ s|</?meta\b[^>]*>||gio);
+    1 while ($$data =~ s|</?link\b[^>]*>||gio);
 
     ## Strip out <font> tags if requested
     if ($nofont) {
 	$$data =~ s|<style[^>]*>.*?</style\s*>||gios;
-	$$data =~ s|</?font\b[^>]*>||gio;
+	1 while ($$data =~ s|</?font\b[^>]*>||gio);
+        1 while ($$data =~ s/\b(?:style|class)\s*=\s*"[^"]*"//gio);
+	1 while ($$data =~ s/\b(?:style|class)\s*=\s*'[^']*'//gio);
+	1 while ($$data =~ s/\b(?:style|class)\s*=\s*[^\s>]+//gio);
+	1 while ($$data =~ s|</?style\b[^>]*>||gi);
+
     }
 
     ## Strip out scripting markup if requested
     if ($noscript) {
+	# remove scripting elements and attributes
 	$$data =~ s|<script[^>]*>.*?</script\s*>||gios;
-	$$data =~ s|<style[^>]*>.*?</style\s*>||gios  unless $nofont;
-	$$data =~ s|$SAttr\s*=\s*"[^"]*"||gio; #"
-	$$data =~ s|$SAttr\s*=\s*'[^']*'||gio; #'
-	$$data =~ s|$SAttr\s*=\s*[^\s>]+||gio;
-	$$data =~ s|</?$SElem[^>]*>||gio;
-
-	# just in-case, make sure all script tags are removed
+	unless ($nofont) {  # avoid dup work if style already stripped
+	    $$data =~ s|<style[^>]*>.*?</style\s*>||gios;
+	    1 while ($$data =~ s|</?style\b[^>]*>||gi);
+	}
+	1 while ($$data =~ s|$SAttr\s*=\s*"[^"]*"||gio); #"
+	1 while ($$data =~ s|$SAttr\s*=\s*'[^']*'||gio); #'
+	1 while ($$data =~ s|$SAttr\s*=\s*[^\s>]+||gio);
+	1 while ($$data =~ s|</?$SElem[^>]*>||gio);
 	1 while ($$data =~ s|</?script\b||gi);
+
 	# for netscape 4.x browsers
-	$$data =~ s/(=\s*["']?\s*)\&\{/$1/g;
+	$$data =~ s/(=\s*["']?\s*)(?:\&\{)+/$1/g;
+
+	# Hopefully complete pattern to neutralize javascript:... URLs.
+	# The pattern is ugly because we have to handle any combination
+	# of regular chars and entity refs.
+	$$data =~ s/\b(?:j|&\#(?:0*(?:74|106)|x0*(?:4a|6a))(?:;|(?![0-9])))
+		      (?:a|&\#(?:0*(?:65|97)|x0*(?:41|61))(?:;|(?![0-9])))
+		      (?:v|&\#(?:0*(?:86|118)|x0*(?:56|76))(?:;|(?![0-9])))
+		      (?:a|&\#(?:0*(?:65|97)|x0*(?:41|61))(?:;|(?![0-9])))
+		      (?:s|&\#(?:0*(?:83|115)|x0*(?:53|73))(?:;|(?![0-9])))
+		      (?:c|&\#(?:0*(?:67|99)|x0*(?:43|63))(?:;|(?![0-9])))
+		      (?:r|&\#(?:0*(?:82|114)|x0*(?:52|72))(?:;|(?![0-9])))
+		      (?:i|&\#(?:0*(?:73|105)|x0*(?:49|69))(?:;|(?![0-9])))
+		      (?:p|&\#(?:0*(?:80|112)|x0*(?:50|70))(?:;|(?![0-9])))
+		      (?:t|&\#(?:0*(?:84|116)|x0*(?:54|74))(?:;|(?![0-9])))
+		   /_javascript_/gix;
+
     }
 
     ## Modify relative urls to absolute using BASE
@@ -230,7 +256,7 @@ sub filter {
 	    $$data = $tpre . $$data . $tsuf;
 	}
     }
-    $$data =~ s|</?body[^>]*>||ig;
+    1 while ($$data =~ s|</?body[^>]*>||ig);
 
     ## Check for CID URLs (multipart/related HTML)
     $$data =~ s/($UAttr\s*=\s*['"])([^'"]+)(['"])/
